NAME = "blue_flie"

ICON = "🦋"

DESCRIPTION = f"{ICON} flying with AI."

VERSION = "4.74.1"

REPO_NAME = "blue-flie"

MARQUEE = "https://www.bitcraze.io/images/documentation/overview/system_overview.jpg"

ALIAS = "@flie"


def fullname() -> str:
    return f"{NAME}-{VERSION}"



from blueness import module
from blue_plugin import NAME
from blue_plugin.logger import logger


NAME = module.name(__file__, NAME)


def func(arg: str) -> bool:
    logger.info(f"{NAME}.func: arg={arg}")
    return True



import argparse

from blueness import module
from blueness.argparse.generic import sys_exit

from blue_flie import NAME
from blue_flie.logger import logger

NAME = module.name(__file__, NAME)

parser = argparse.ArgumentParser(NAME)
parser.add_argument(
    "task",
    type=str,
    help="",
)
args = parser.parse_args()

success = False
if args.task == "task":
    success = False
else:
    success = None

sys_exit(logger, NAME, args.task, success)



import os

from blue_options.help.functions import get_help
from blue_objects import file, README

from blue_flie import NAME, VERSION, ICON, REPO_NAME
from blue_flie.help.functions import help_functions


items = README.Items(
    [
        {
            "name": "Swarm Simulation",
            "marquee": "https://github.com/kamangir/assets/blob/main/gazebo-gif-1/gazebo-gif-1.gif?raw=true",
            "description": "Simulating harm/cost for drone swarms with [Gazebo](https://gazebosim.org/home).",
            "url": "./blue_flie/docs/gazebo.md",
        },
        {
            "name": "blue Crazy",
            "marquee": "https://www.bitcraze.io/images/documentation/overview/system_overview.jpg",
            "description": "based on [Crazyflie 2.1 Brushless](https://www.bitcraze.io/products/crazyflie-2-1-brushless/)",
            "url": "./blue_flie/docs/blue-crazy.md",
        },
        {
            "name": "blue Beast",
            "marquee": "https://github.com/waveshareteam/ugv_rpi/raw/main/media/UGV-Rover-details-23.jpg",
            "description": "based on [UGV Beast PI ROS2](https://www.waveshare.com/wiki/UGV_Beast_PI_ROS2)",
            "url": "https://github.com/kamangir/blue-rover/blob/main/blue_rover/docs/blue-beast.md",
        },
        {
            "name": "blue Amo",
            "marquee": "https://github.com/kamangir/assets/blob/main/blue-amo-2025-02-03-zjs1ow/generating-frame-006.png?raw=true",
            "description": "Concept development with AI",
            "url": "https://github.com/kamangir/blue-assistant/blob/main/blue_assistant/script/repository/blue_amo/README.md",
        },
    ]
)


def build():
    return all(
        README.build(
            items=readme.get("items", []),
            cols=readme.get("cols", 3),
            path=os.path.join(file.path(__file__), readme["path"]),
            ICON=ICON,
            NAME=NAME,
            VERSION=VERSION,
            REPO_NAME=REPO_NAME,
            help_function=lambda tokens: get_help(
                tokens,
                help_functions,
                mono=True,
            ),
        )
        for readme in [
            {
                "items": items,
                "cols": 2,
                "path": "..",
            },
        ]
        + [
            {
                "path": f"docs/{suffix}.md",
            }
            for suffix in ["gazebo", "blue-crazy"]
            + ["gazebo-{:02d}".format(index + 1) for index in range(3)]
        ]
    )



from typing import List

from abcli.host import signature as abcli_signature
from blue_sbc import fullname as blue_sbc_fullname

from blue_flie import fullname


def signature() -> List[str]:
    return [
        fullname(),
        blue_sbc_fullname(),
    ] + abcli_signature()



from typing import List

from blue_options.terminal import show_usage, xtra


def help_install(
    tokens: List[str],
    mono: bool,
) -> str:
    options = xtra("dryrun", mono=mono)

    return show_usage(
        [
            "toolbelt",
            "install",
            f"[{options}]",
        ],
        "install toolbelt.",
        mono=mono,
    )


help_functions = {
    "install": help_install,
}



from typing import List

from blue_options.terminal import show_usage, xtra

example_details = {
    "examples: https://github.com/gazebosim/gz-sim/examples/worlds/": [],
}

fuel_details = {
    "fuel: https://app.gazebosim.org/fuel": [],
}


def browse_options(
    mono: bool,
    cascade: bool = False,
):
    return "".join(
        [
            xtra(
                "dryrun,",
                mono=mono,
            ),
            (
                ""
                if cascade
                else xtra(
                    "~download,",
                    mono=mono,
                )
            ),
            xtra(
                "filename=<filename.sdf>,~gif,install,~pictures,~upload",
                mono=mono,
            ),
        ]
    )


def help_browse(
    tokens: List[str],
    mono: bool,
) -> str:

    return show_usage(
        [
            "@gazebo",
            "browse",
            f"[{browse_options(mono=mono)}]",
            "[-|<object-name>]",
        ],
        "browse <object-name> in gazebo.",
        mono=mono,
    )


def help_ingest(
    tokens: List[str],
    mono: bool,
) -> str:
    options = xtra("dryrun,~upload", mono=mono)

    source_options = "example=<example-name> | fuel=<fuel-name>"

    return show_usage(
        [
            "@gazebo",
            "ingest",
            f"[{options}]",
            f"[{source_options}]",
            "[-|<object-name>]",
            "[browse,{}]".format(
                browse_options(
                    mono=mono,
                    cascade=True,
                )
            ),
        ],
        "ingest <example-name> -> <object-name>.",
        {
            **example_details,
            **fuel_details,
        },
        mono=mono,
    )


def help_ingest_list(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@gazebo",
            "ingest",
            "list",
        ],
        "list gazebo examples.",
        {
            **example_details,
        },
        mono=mono,
    )


def help_install(
    tokens: List[str],
    mono: bool,
) -> str:
    options = xtra("dryrun", mono=mono)

    return show_usage(
        [
            "@gazebo",
            "install",
            f"[{options}]",
        ],
        "install gazebo.",
        mono=mono,
    )


help_functions = {
    "browse": help_browse,
    "ingest": {
        "": help_ingest,
        "list": help_ingest_list,
    },
    "install": help_install,
}
